==> 1.1.6.tar.gz: generate_consts.sh <==
filename='pubspec.yaml'

which_version_number(){
    echo ''
    echo ''
    echo 'updating package version.......'
    echo ''
    echo ''

    IN=$2
    arrIN=(${IN//./ })
    major=${arrIN[0]}
    minor=${arrIN[1]}
    patch=${arrIN[2]}
    
    if (($patch == 9))
    then
        patch=0
        minor=$(($minor + 1))
        if (($minor == 10))
        then 
            minor=0
            major=$(($major + 1))
        fi
    else
        patch=$(($patch + 1))
    fi
    
    final="$major.$minor.$patch"
    sed -i "" "s/$IN/$final/" $filename
    echo "new version number: $final"
    exit 1
}

update_package_version()
{
    echo ''
    echo ''
    echo 'looking for version line...'
    echo ''
    echo ''
    while read line; do
    if [[ $line == version:* ]]; then
        echo 'LINE FOUND'
        which_version_number $line
        return
    fi

    done < $filename
}

generate_constants()
{
    echo 'Generating Constants...'
    echo ''
    echo ''
    python3 constants/buildscripts/createErrors.py Dart constants/errors.json templates/errors_template.dart lib/classes/gen/errors.dart ble
    python3 constants/buildscripts/createDataSources.py Dart constants/dataSourceIds.json templates/datasources_template.dart lib/classes/gen/data_sources.dart ble
    python3 constants/buildscripts/createDeviceTypes.py Dart constants/deviceTypes.json templates/device_types_template.dart lib/classes/gen/device_types.dart ble
    python3 constants/buildscripts/createEventIds.py Dart constants/eventIDs.json templates/events_template.dart lib/classes/gen/event_ids.dart ble
    python3 constants/buildscripts/createPropertyIds.py Dart constants/propertyIDs.json templates/properties_template.dart lib/classes/gen/property_ids.dart ble
    update_package_version
}


generate_constants

==> 1.1.9.tar.gz: generate_consts.sh <==
# to run git subtree pull instead of generate constants
# add an argument (can be anything) after ./generate_consts.sh
# example: ./generate_consts.sh yes
# to run normally (no git subtree pull) just use ./generate_consts.sh

filename='pubspec.yaml'
readme='README.md'

update_in_readme()
{
    echo ''
    echo ''
    echo 'updating README version.......'
    echo ''
    echo ''
    while read line; do
    if [[ $line == capture_flutter_beta:* ]]; then
        echo 'LINE FOUND'
        sed -i "" "s/$1/$2/" $readme
        echo "new version number in README.md: $2"
        exit 1
    fi

    done < $readme
}

which_version_number()
{   
    echo $2
    echo ''
    echo ''
    echo 'updating package version.......'
    echo ''
    echo ''

    IN=$2
    arrIN=(${IN//./ })
    major=${arrIN[0]}
    minor=${arrIN[1]}
    patch=${arrIN[2]}
    
    if (($patch == 9))
    then
        patch=0
        minor=$(($minor + 1))
        if (($minor == 10))
        then 
            minor=0
            major=$(($major + 1))
        fi
    else
        patch=$(($patch + 1))
    fi
    
    final="$major.$minor.$patch"
    sed -i "" "s/$IN/$final/" $filename
    echo "new version number: $final"
    # exit 1
    update_in_readme $IN $final 
}

update_package_version()
{
    echo ''
    echo ''
    echo 'looking for version line...'
    echo ''
    echo ''
    while read line; do
    if [[ $line == version:* ]]; then
        echo 'LINE FOUND'
        which_version_number $line
        return
    fi

    done < $filename
}

generate_constants_pt_two()
{
    echo 'Generating Constants...'
    echo ''
    echo ''
    python3 constants/buildscripts/createErrors.py Dart constants/errors.json templates/errors_template.dart lib/classes/gen/errors.dart ble
    python3 constants/buildscripts/createDataSources.py Dart constants/dataSourceIds.json templates/datasources_template.dart lib/classes/gen/data_sources.dart ble
    python3 constants/buildscripts/createDeviceTypes.py Dart constants/deviceTypes.json templates/device_types_template.dart lib/classes/gen/device_types.dart ble
    python3 constants/buildscripts/createEventIds.py Dart constants/eventIDs.json templates/events_template.dart lib/classes/gen/event_ids.dart ble
    python3 constants/buildscripts/createPropertyIds.py Dart constants/propertyIDs.json templates/properties_template.dart lib/classes/gen/property_ids.dart ble
    update_package_version
}

if [ -z "$1"]; then
    generate_constants_pt_two
else
    echo 'Getting Constants from Subtree...'
    echo ''
    echo ''
    git subtree pull --prefix constants git@git.socketmobile.com:scanning/captureconstants-universal.git master --squash
fi
